Доклади | OiRA

Теми

# Доклади

Можете да изготвите доклад с цел:

- да предоставите доказателства на надзорните органи;
- да предоставите информация на заинтересовани лица (работещи лица, представители по безопасността, работодатели, експерти по безопасност и здраве при работа и др.);
- да извършите наблюдение и да оцените дали са предприети необходимите мерки;
- да документирате изменения в отговор на променени обстоятелства (нови машини / работници или в резултат на констатации от разследвания злополуки и т.н.).

Можете да запишете доклада в паметта на вашия компютър и да го отпечатате. Можете също да го редактирате или да добавите допълнителна информация. Обърнете внимание, че всички промени, внесени в доклад, който сте изтеглили на вашия компютър, НЯМА да бъдат съхранени в инструмента OiRA.

## Налични видове доклади

Има различни видове доклади, предназначени за различни цели. Изборът на наличните доклади във връзка с отделните инструменти зависи от решенията на националния партньор на OiRA / разработчик на инструменти.

Налични доклади.

### Пълен доклад

Формат: Word / Office Open XML (.docx). Можете да редактирате доклада, след като го изтеглите.

Съдържа: цялата информация и данни, вписани от вас на всички етапи на процеса на оценка на риска.

Използвайте доклада: за да предоставите доказателства за оценката на риска на надзорните органи (напр. инспекцията по труда).

### План за действие

Формат: Excel / Office Open XML (.xlsx). Можете да редактирате доклада, след като го изтеглите

Съдържа: информация за всички предприети от вас мерки.

Използвайте доклада:

- за активно осъществяване на последващи действия във връзка с предприетите от вас мерки;
- управление на проблемите / рисковете на работното място (специфични задачи, експертен капацитет, отговорности, срокове).

### Преглед на риска

Формат: Portable Document Format (.pdf). Не можете да редактирате доклада, след като го изтеглите.

Съдържа: преглед на идентифицираните рискове

Използвайте доклада:

- за да получите бърз преглед на състоянието на рисковете на работното място;
- за предаване на информацията на заинтересованите лица;
- за проследяване дали са предприети съответни действия по отношение на рисковете / мерките.

### Преглед на мерките

Формат: Portable Document Format (.pdf). Не можете да редактирате доклада, след като го изтеглите.

Съдържа: бърз преглед на мерките, които трябва да бъдат изпълнени.

Използвайте доклада:

- за да получите бърз преглед на състоянието на мерките, които сте предприели;
- за предаване на информацията на заинтересованите лица;
- за проследяване дали са предприети съответни действия по отношение на рисковете / мерките.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More